@@ -9,23 +9,33 @@ from typing import TYPE_CHECKING
 
 from packaging.utils import canonicalize_name
 from poetry.core.packages.package import Package
+from poetry.core.packages.utils.utils import is_python_project
 from poetry.core.packages.utils.utils import url_to_path
 from poetry.core.utils.helpers import module_name
 
 from poetry.repositories.repository import Repository
+from poetry.utils._compat import getencoding
 from poetry.utils._compat import metadata
+from poetry.utils.env import VirtualEnv
 
 
 if TYPE_CHECKING:
-    from poetry.utils.env import Env
+    from collections.abc import Sequence
 
+    from poetry.utils.env import Env
 
 logger = logging.getLogger(__name__)
 
 
 class InstalledRepository(Repository):
-    def __init__(self) -> None:
-        super().__init__("poetry-installed")
+    def __init__(self, packages: Sequence[Package] | None = None) -> None:
+        super().__init__("poetry-installed", packages)
+        self.system_site_packages: list[Package] = []
+
+    def add_package(self, package: Package, *, is_system_site: bool = False) -> None:
+        super().add_package(package)
+        if is_system_site:
+            self.system_site_packages.append(package)
 
     @classmethod
     def get_package_paths(cls, env: Env, name: str) -> set[Path]:
@@ -58,7 +68,7 @@ class InstalledRepository(Repository):
             if not pth_file.exists():
                 continue
 
-            with pth_file.open() as f:
+            with pth_file.open(encoding=getencoding()) as f:
                 for line in f:
                     line = line.strip()
                     if line and not line.startswith(("#", "import ", "import\t")):
@@ -96,18 +106,16 @@ class InstalledRepository(Repository):
             return True
 
     @classmethod
-    def create_package_from_distribution(
-        cls, distribution: metadata.Distribution, env: Env
+    def _create_package_from_distribution(
+        cls, path: Path, dist_metadata: metadata.PackageMetadata, env: Env
     ) -> Package:
         # We first check for a direct_url.json file to determine
         # the type of package.
-        path = Path(str(distribution._path))  # type: ignore[attr-defined]
-
         if (
             path.name.endswith(".dist-info")
             and path.joinpath("direct_url.json").exists()
         ):
-            return cls.create_package_from_pep610(distribution)
+            return cls._create_package_from_pep610(path, dist_metadata)
 
         is_standard_package = env.is_path_relative_to_lib(path)
 
@@ -118,9 +126,7 @@ class InstalledRepository(Repository):
         source_subdirectory = None
         if is_standard_package:
             if path.name.endswith(".dist-info"):
-                paths = cls.get_package_paths(
-                    env=env, name=distribution.metadata["name"]
-                )
+                paths = cls.get_package_paths(env=env, name=dist_metadata["name"])
                 if paths:
                     is_editable_package = False
                     for src in paths:
@@ -140,23 +146,25 @@ class InstalledRepository(Repository):
                         # TODO: handle multiple source directories?
                         if is_editable_package:
                             source_type = "directory"
-                            source_url = paths.pop().as_posix()
+                            path = paths.pop()
+                            if path.name == "src":
+                                path = path.parent
+                            source_url = path.as_posix()
         elif cls.is_vcs_package(path, env):
             (
                 source_type,
                 source_url,
                 source_reference,
             ) = cls.get_package_vcs_properties_from_path(
-                env.path / "src" / canonicalize_name(distribution.metadata["name"])
+                env.path / "src" / canonicalize_name(dist_metadata["name"])
             )
-        else:
-            # If not, it's a path dependency
+        elif is_python_project(path.parent):
             source_type = "directory"
             source_url = str(path.parent)
 
         package = Package(
-            distribution.metadata["name"],
-            distribution.metadata["version"],
+            dist_metadata["name"],
+            dist_metadata["version"],
             source_type=source_type,
             source_url=source_url,
             source_reference=source_reference,
@@ -164,7 +172,7 @@ class InstalledRepository(Repository):
             source_subdirectory=source_subdirectory,
         )
 
-        package.description = distribution.metadata.get(  # type: ignore[attr-defined]
+        package.description = dist_metadata.get(  # type: ignore[attr-defined]
             "summary",
             "",
         )
@@ -172,8 +180,9 @@ class InstalledRepository(Repository):
         return package
 
     @classmethod
-    def create_package_from_pep610(cls, distribution: metadata.Distribution) -> Package:
-        path = Path(str(distribution._path))  # type: ignore[attr-defined]
+    def _create_package_from_pep610(
+        cls, path: Path, dist_metadata: metadata.PackageMetadata
+    ) -> Package:
         source_type = None
         source_url = None
         source_reference = None
@@ -210,8 +219,8 @@ class InstalledRepository(Repository):
         source_subdirectory = url_reference.get("subdirectory")
 
         package = Package(
-            distribution.metadata["name"],
-            distribution.metadata["version"],
+            dist_metadata["name"],
+            dist_metadata["version"],
             source_type=source_type,
             source_url=source_url,
             source_reference=source_reference,
@@ -220,7 +229,7 @@ class InstalledRepository(Repository):
             develop=develop,
         )
 
-        package.description = distribution.metadata.get(  # type: ignore[attr-defined]
+        package.description = dist_metadata.get(  # type: ignore[attr-defined]
             "summary",
             "",
         )
@@ -238,7 +247,13 @@ class InstalledRepository(Repository):
         seen = set()
         skipped = set()
 
-        for entry in reversed(env.sys_path):
+        base_env = (
+            env.parent_env
+            if isinstance(env, VirtualEnv) and env.includes_system_site_packages
+            else None
+        )
+
+        for entry in env.sys_path:
             if not entry.strip():
                 logger.debug(
                     "Project environment contains an empty path in <c1>sys_path</>,"
@@ -255,8 +270,13 @@ class InstalledRepository(Repository):
                 if path in skipped:
                     continue
 
-                name = distribution.metadata.get("name")  # type: ignore[attr-defined]
-                if name is None:
+                dist_metadata = distribution.metadata  # type: ignore[attr-defined]
+                name = (
+                    dist_metadata.get("name")  # type: ignore[attr-defined]
+                    if dist_metadata
+                    else None
+                )
+                if not dist_metadata or name is None:
                     logger.warning(
                         "Project environment contains an invalid distribution"
                         " (<c1>%s</>). Consider removing it manually or recreate"
@@ -271,14 +291,21 @@ class InstalledRepository(Repository):
                 if name in seen:
                     continue
 
-                package = cls.create_package_from_distribution(distribution, env)
+                package = cls._create_package_from_distribution(
+                    path, dist_metadata, env
+                )
 
                 if with_dependencies:
-                    for require in distribution.metadata.get_all("requires-dist", []):
+                    for require in dist_metadata.get_all("requires-dist", []):
                         dep = Dependency.create_from_pep_508(require)
                         package.add_dependency(dep)
 
                 seen.add(package.name)
-                repo.add_package(package)
+                repo.add_package(
+                    package,
+                    is_system_site=bool(
+                        base_env and base_env.is_path_relative_to_lib(path)
+                    ),
+                )
 
         return repo
